@@ -92,35 +92,20 @@ class Entry(BaseElement):
         if field is not None:
             return field.text
 
-    def _set_string_field(self, key, value, protected=None):
+    def _set_string_field(self, key, value, protected=True):
         """Create or overwrite a string field in an Entry
 
         Args:
             key (str): name of field
             value (str): value of field
-            protected (bool or None): mark whether the field should be protected in memory
-                in other tools.  If None, value is either copied from existing field or field
-                is created with protected property unset.
-
-        Note: pykeepass does not support memory protection
+            protected (bool): mark whether the field should be protected in memory
+                in other tools.  This property is ignored in PyKeePass and all
+                fields are decrypted immediately upon opening the database.
         """
         field = self._xpath('String/Key[text()="{}"]/..'.format(key), history=True, first=True)
-
-        protected_str = None
-        if protected is None:
-            protected_field = self._xpath('String/Key[text()="{}"]/../Value'.format(key), first=True)
-            if protected_field is not None:
-                protected_str = protected_field.attrib.get("Protected")
-        else:
-            protected_str = str(protected)
-
         if field is not None:
             self._element.remove(field)
-
-        if protected_str is None:
-            self._element.append(E.String(E.Key(key), E.Value(value)))
-        else:
-            self._element.append(E.String(E.Key(key), E.Value(value, Protected=protected_str)))
+        self._element.append(E.String(E.Key(key), E.Value(value, Protected=str(protected))))
 
     def _get_string_field_keys(self, exclude_reserved=False):
         results = [x.find('Key').text for x in self._element.findall('String')]
@@ -198,10 +183,7 @@ class Entry(BaseElement):
 
     @password.setter
     def password(self, value):
-        if self.password:
-            return self._set_string_field('Password', value)
-        else:
-            return self._set_string_field('Password', value, True)
+        return self._set_string_field('Password', value)
 
     @property
     def url(self):
@@ -234,7 +216,7 @@ class Entry(BaseElement):
     def tags(self):
         """str: get or set entry tags"""
         val = self._get_subelement_text('Tags')
-        return val.replace(',', ';').split(';') if val else []
+        return val.replace(',', ';').split(';') if val else val
 
     @tags.setter
     def tags(self, value, sep=';'):
@@ -249,10 +231,7 @@ class Entry(BaseElement):
 
     @otp.setter
     def otp(self, value):
-        if self.otp:
-            return self._set_string_field('otp', value)
-        else:
-            return self._set_string_field('otp', value, True)
+        return self._set_string_field('otp', value)
 
     @property
     def history(self):
@@ -359,10 +338,6 @@ class Entry(BaseElement):
 
         """
         assert key not in reserved_keys, '{} is a reserved key'.format(key)
-        return self._is_property_protected(key)
-
-    def _is_property_protected(self, key):
-        """Whether a property is protected."""
         field = self._xpath('String/Key[text()="{}"]/../Value'.format(key), first=True)
         if field is not None:
             return field.attrib.get("Protected", "False") == "True"
